using System;
using Server;
using Server.Items;

namespace Server.Mobiles
{
	[CorpseName( "a godly corpse" )]
	public class Neptune : BaseCreature
	{
		[Constructable]
		public Neptune() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "Neptune king of the sea";
			Body = 76;
			BaseSoundID = 367;
			Hue = 1282;

			SetStr( 550, 600 );
			SetDex( 136, 155 );
			SetInt( 165, 185 );

			SetHits( 3475, 4525 );
			SetMana( 0 );

			SetDamage( 15, 26 );

			SetDamageType( ResistanceType.Physical, 80 );
			SetDamageType( ResistanceType.Fire, 10 );

			SetResistance( ResistanceType.Physical, 70, 90 );
			SetResistance( ResistanceType.Fire, 95, 100 );
			SetResistance( ResistanceType.Cold, 75, 95 );
			SetResistance( ResistanceType.Poison, 70, 90 );
			SetResistance( ResistanceType.Energy, 70, 90 );

			SetSkill( SkillName.Anatomy, 95.1, 100.0 );
			SetSkill( SkillName.MagicResist, 100.2, 105.0 );
			SetSkill( SkillName.Tactics, 90.1, 100.0 );
			SetSkill( SkillName.Wrestling, 85.1, 105.0 );

			Fame = 120500;
			Karma = -120500;

			VirtualArmor = 53;

			PackGold( 450, 500 );

			switch ( Utility.Random( 50 )) 
          		{ 
            		case 0: PackItem( new NeptunesRing() ); break; 
            		case 1: PackItem( new NeptunesTrident() ); break; 
            		default: break; 
          		} 
		}
		public override void GenerateLoot()
		{
			AddLoot( LootPack.UltraRich );
		}

		public override bool HasBreath{ get{ return true; } } // fire breath enabled
		public override int BreathEffectSound{ get{ return 0x347; } }
		public override int Meat{ get{ return 4; } }
		public override int TreasureMapLevel{ get{ return 3; } }
		public override int Hides{ get{ return 20; } }
		public override HideType HideType{ get{ return HideType.Horned; } }

		public Neptune( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}