using System;
using System.Collections;
using Server.Items;
using Server.Targeting;

namespace Server.Mobiles
{
	[CorpseName( "an sea daemon corpse" )]
	public class SeaDaemon : BaseCreature
	{
		[Constructable]
		public SeaDaemon() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Name = "an sea daemon";
			Body = 787;
			BaseSoundID = 1006;
			Hue = 1282;

			SetStr( 296, 320 );
			SetDex( 81, 105 );
			SetInt( 36, 60 );

			SetHits( 251, 462 );

			SetDamage( 7, 21 );

			SetDamageType( ResistanceType.Physical, 70 );
			SetDamageType( ResistanceType.Poison, 30 );

			SetResistance( ResistanceType.Physical, 45, 60 );
			SetResistance( ResistanceType.Fire, 95, 100 );
			SetResistance( ResistanceType.Cold, 30, 40 );
			SetResistance( ResistanceType.Poison, 40, 50 );
			SetResistance( ResistanceType.Energy, 30, 35 );

			SetSkill( SkillName.MagicResist, 70.0 );
			SetSkill( SkillName.Tactics, 90.0 );
			SetSkill( SkillName.Wrestling, 90.0 );

			Fame = 4500;
			Karma = -4500;

			VirtualArmor = 45;

			PackGold( 250, 350 );

			int amount = Utility.RandomMinMax( 1, 10 );

			switch ( Utility.Random( 4 ) )
			{
				case 0: PackItem( new DullCopperOre( amount ) ); break;
				case 1: PackItem( new ShadowIronOre( amount ) ); break;
				case 2: PackItem( new CopperOre( amount ) ); break;
				case 3: PackItem( new BronzeOre( amount ) ); break;
			}

			// TODO: 1-5 fertile dirt
			// TODO: skeleton
		}
		public override void GenerateLoot()
		{
			AddLoot( LootPack.FilthyRich );
		}

		public override int GetAngerSound()
		{
			return 0x5A;
		}

		public override int GetIdleSound()
		{
			return 0x5A;
		}

		public override int GetAttackSound()
		{
			return 0x164;
		}

		public override int GetHurtSound()
		{
			return 0x187;
		}

		public override int GetDeathSound()
		{
			return 0x1BA;
		}

		public SeaDaemon( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}