using System;
using Server.Mobiles;

namespace Server.Mobiles
{
	[CorpseName("a deadly water serpent corpse")]
	public class WaterSerpent : BaseCreature
	{
		[Constructable]
		public WaterSerpent() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Body = 92;
			Name = "a deadly water serpent";

			SetStr( 161, 360 );
			SetDex( 151, 300 );
			SetInt( 21, 40 );
			Hue = 1282;

			SetHits( 97, 216 );

			SetDamage( 5, 21 );

			SetDamageType( ResistanceType.Physical, 50 );
			SetDamageType( ResistanceType.Poison, 50 );

			SetResistance( ResistanceType.Physical, 35, 45 );
			SetResistance( ResistanceType.Fire, 95, 100 );
			SetResistance( ResistanceType.Cold, 5, 10 );
			SetResistance( ResistanceType.Poison, 100 );
			SetResistance( ResistanceType.Energy, 5, 10 );

			SetSkill( SkillName.Poisoning, 90.1, 100.0 );
			SetSkill( SkillName.MagicResist, 95.1, 100.0 );
			SetSkill( SkillName.Tactics, 80.1, 95.0 );
			SetSkill( SkillName.Wrestling, 85.1, 100.0 );

			Fame = 7000;
			Karma = -7000;

			VirtualArmor = 40;

			PackGold( 550, 700 );
		}
		public override void GenerateLoot()
		{
			AddLoot( LootPack.FilthyRich );
		}

		public override int Meat{ get{ return 1; } }
		public override Poison PoisonImmune{ get{ return Poison.Lethal; } }
		public override Poison HitPoison{ get{ return Poison.Lethal; } }

		public WaterSerpent(Serial serial) : base(serial)
		{
		}

		public override int GetIdleSound() 
		{ 
			return 0x1BF; 
		} 

		public override int GetAttackSound() 
		{ 
			return 0x1C0; 
		} 

		public override int GetHurtSound() 
		{ 
			return 0x1C1; 
		} 

		public override int GetDeathSound() 
		{ 
			return 0x1C2; 
		} 

		public override void Serialize(GenericWriter writer)
		{
			base.Serialize(writer);

			writer.Write((int) 0);
		}

		public override void Deserialize(GenericReader reader)
		{
			base.Deserialize(reader);

			int version = reader.ReadInt();
		}
	}
}